exponential_histogram_gate

Function exponential_histogram_gate 

pub(crate) fn exponential_histogram_gate(
    histogram: &ExponentialHistogram,
    metric_ctx: &OtlpMetricCtx,
) -> Result<(), ExponentialHistogramRejection>
Whole-metric acceptance, decided once for the encoder and for the resource descriptor, which must not describe a resource whose data was rejected. Individual points can still fail exponential_histogram_value.